// sim_eq.h
//============================================================
// Solves the set of simultaneous equations, Ax=y.                         
//------------------------------------------------------------
int sim_eq (double A[], double Y[], double X[], int n)
 {
  double  ACOPY[n+1][n+1], YCOPY[n+1], T1, T2;
  int     I, J, K, NROW[n+1], ERROR=0;

  for (I=1;I<=n;I++) {
    K=1, T1 = fabs(A[I*n+1]);
    for (J=2;J<=n;J++) {
      T2 = fabs(A[I*n+J]);
      if (T2>T1) {
        K=J, T1=T2;
      }
    }
    for (J=1;J<=n;J++) ACOPY[I][J] = A[I*n+J]/T1;
    YCOPY[I] = Y[I]/T1; 
    NROW[I] = I;
  }

  for (I=1;I<n;I++) {
    K=I, T1=fabs(ACOPY[NROW[I]][I]);
    for (J=I+1;J<=n;J++) { 
      T2=fabs(ACOPY[NROW[J]][I]);
      if (T2>T1) {
        K=J, T1=T2;
      }
    }
    if (fabs(T1)<1.0e-15) ERROR=1;
    J=NROW[I], NROW[I]=NROW[K], NROW[K]=J;  

    for (J=I+1;J<=n;J++) {
      T1 = ACOPY[NROW[J]][I]/ACOPY[NROW[I]][I];
      for (K=I+1;K<=n;K++) 
        ACOPY[NROW[J]][K] -= T1*ACOPY[NROW[I]][K];
      YCOPY[NROW[J]] -= T1*YCOPY[NROW[I]];
    }
  }
  if (fabs(ACOPY[NROW[n]][n])<1.0e-15) ERROR=2;

  for (I=n;I>0;I--) {
    T1 = YCOPY[NROW[I]];
    for (J=I+1;J<=n;J++) T1 -= X[J]*ACOPY[NROW[I]][J];
    X[I] = T1/ACOPY[NROW[I]][I];
  }

  return ERROR;
 }  
